@@ -6,6 +6,7 @@ import { inspect } from 'util';
 import { formatISO9075 } from 'date-fns';
 
 import {
+  ADMINISTRATION_FREQUENCIES,
   CURRENTLY_AT_TYPES,
   DAYS_OF_WEEK,
   DIAGNOSIS_CERTAINTY_VALUES,
@@ -201,12 +202,7 @@ export function fakePrescription(prefix: string = 'test-') {
   return {
     date: formatISO9075(chance.date()),
     endDate: formatISO9075(chance.date()),
-    ...fakeStringFields(`${prefix}prescription${id}_`, [
-      'id',
-      'note',
-      'indication',
-      'route',
-    ]),
+    ...fakeStringFields(`${prefix}prescription${id}_`, ['id', 'note', 'indication', 'route']),
   };
 }
 
@@ -361,6 +357,12 @@ const MODEL_SPECIFIC_OVERRIDES = {
     id: `${patientId.replaceAll(';', ':')};${programRegistryId.replaceAll(';', ':')}`,
     registrationStatus: REGISTRATION_STATUSES.ACTIVE,
   }),
+  Prescription: () => ({
+    frequency: chance.pickone(Object.values(ADMINISTRATION_FREQUENCIES)),
+    discontinued: false,
+    endDate: null,
+    idealTimes: null,
+  }),
   User: () => ({
     email: chance.email({ length: 20 }),
     displayId: chance.hash({ length: 5 }),
